@@ -289,6 +289,16 @@ class RSGISPyUtils (object):
                 os.rmdir(os.path.join(root, name))
         os.rmdir(dirPath)
         print("Deleted " + dirPath)
+        
+    def renameGDALLayer(self, cFileName, oFileName):
+        """
+        Rename all the files associated with a GDAL layer.
+        """
+        import osgeo.gdal as gdal
+        layerDS = gdal.Open(cFileName, gdal.GA_ReadOnly)
+        gdalDriver = layerDS.GetDriver()
+        layerDS = None
+        gdalDriver.Rename(oFileName, cFileName)
 
     def getRSGISLibDataType(self, gdaltype):
         """ Convert from GDAL data type string to 
@@ -378,6 +388,24 @@ class RSGISPyUtils (object):
         brY = tlY + (yRes * ySize)
         
         return [tlX, brX, tlY, brY]
+        
+    def reprojPoint(self, inProjOSRObj, outProjOSRObj, x, y):
+        """
+        Reproject a point from 'inProjOSRObj' to 'outProjOSRObj' where they are gdal
+        osgeo.osr.SpatialReference objects. 
+        
+        Returns x, y. (note if returning long, lat you might need to invert)
+        """
+        import osgeo.gdal as gdal
+        import osgeo.ogr as ogr
+        import osgeo.osr as osr
+        wktPt = 'POINT(%s %s)' % (x, y)
+        point = ogr.CreateGeometryFromWkt(wktPt)
+        point.AssignSpatialReference(inProjOSRObj)
+        point.TransformTo(outProjOSRObj)
+        outX = point.GetY()
+        outY = point.GetX()
+        return outX, outY
     
     def getImageBandCount(self, inImg):
         """
@@ -463,6 +491,44 @@ class RSGISPyUtils (object):
                     utmZone = utmZone+'N'
         return utmZone
     
+    def getEPSGCode(self, gdalLayer):
+        """
+        Using GDAL to return the EPSG code for the input layer.
+        """
+        from osgeo import osr
+        import osgeo.gdal as gdal
+        epsgCode = None
+        try:
+            layerDS = gdal.Open(gdalLayer, gdal.GA_ReadOnly)
+            if layerDS == None:
+                raise RSGISPyException('Could not open raster image: \'' + gdalLayer+ '\'')
+            projStr = layerDS.GetProjection()
+            layerDS = None
+            
+            spatRef = osr.SpatialReference()
+            spatRef.ImportFromWkt(projStr)            
+            spatRef.AutoIdentifyEPSG()
+            epsgCode = spatRef.GetAuthorityCode(None)
+        except Exception:
+            epsgCode = None
+        return epsgCode
+        
+    def doGDALLayersHaveSameProj(self, layer1, layer2):
+        """
+        A function which tests whether two gdal compatiable layers are in the same
+        projection/coordinate system. This is done using the GDAL SpatialReference
+        function AutoIdentifyEPSG. If the identified EPSG codes are different then 
+        False is returned otherwise True.
+        """
+        layer1EPSG = self.getEPSGCode(layer1)
+        layer2EPSG = self.getEPSGCode(layer2)
+        
+        sameESPG = False
+        if layer1EPSG == layer2EPSG:
+            sameESPG = True
+        
+        return sameESPG
+    
     def uidGenerator(self, size=6):
         """
         A function which will generate a 'random' string of the specified length based on the UUID
